"""common func for opencv-python 
"""

from functools import lru_cache
import operator
import cv2
import numpy as np


@lru_cache(5)
def inferThickness(wid: int, hei: int):
    return max(min(wid, hei)//300, 1)


@lru_cache(5)
def inferRadius(wid: int, hei: int):
    return max(min(wid, hei)//200, 3)


def rectangle(
        src,
        pt1, pt2,
        color = (0, 255, 0),
        thickness = None,
        shadowOffset = None
) -> np.ndarray:
    dst = src.copy()
    thickness = thickness or inferThickness(*dst.shape[:2])
    shadowOffset = shadowOffset or (max(thickness//2, 1), max(thickness//2, 1))
    s_pt1 = tuple(map(operator.add, pt1, shadowOffset))
    s_pt2 = tuple(map(operator.add, pt2, shadowOffset))
    dst[:] = cv2.rectangle(dst, s_pt1, s_pt2, (0, 0, 0), thickness)
    dst[:] = cv2.rectangle(dst, pt1, pt2, color, thickness)
    return dst


def circle(
    src: np.ndarray,
    center,
    radius = None,
    color = (0, 255, 0),
    thickness: int = -1,
    shadowOffset = None
):
    dst = src.copy()
    radius = radius or inferRadius(*dst.shape[:2])
    shadowOffset = shadowOffset or (max(radius//3, 1), max(radius//3, 1))
    s_center = tuple(map(operator.add, center, shadowOffset))
    dst[:] = cv2.circle(dst, s_center, radius, (0, 0, 0),
                        thickness, cv2.LINE_AA)
    dst[:] = cv2.circle(dst, center, radius, color, thickness, cv2.LINE_AA)
    return dst


def size(src: np.ndarray):
    return src.shape[1::-1]



def getKARSizeByFitMaxSize(srcSize, maxSize):
    srcRatio = srcSize[0]/srcSize[1]
    tarRatio = maxSize[0]/maxSize[1]

    _, fitMaxArg = np.argsort([srcRatio, tarRatio])

    dstSize = tuple(
        map(int, map((maxSize[fitMaxArg] / srcSize[fitMaxArg]).__mul__, srcSize)))
    return dstSize
